==> org.jfree.skijagraphics2d-1.0.3-sources.jar: org/jfree/skija/TypefaceKey.java <==
/* ===============
 * SkijaGraphics2D
 * ===============
 *
 * (C)opyright 2021, by Object Refinery Limited.
 *
 * The SkijaGraphics2D class has been developed by Object Refinery Limited for
 * use with Orson Charts (http://www.object-refinery.com/orsoncharts) and
 * JFreeChart (http://www.jfree.org/jfreechart).  It may be useful for other
 * code that uses the Graphics2D API provided by Java2D.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *   - Neither the name of the Object Refinery Limited nor the
 *     names of its contributors may be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL OBJECT REFINERY LIMITED BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

package org.jfree.skija;

import org.jetbrains.skija.FontStyle;

/**
 * A key used to identify a {@code Typeface} in a map used to cache items.
 */
public class TypefaceKey {

    private final String fontName;

    private final FontStyle style;

    /**
     * Creates a new key.
     *
     * @param fontName  the font name.
     * @param style  the style.
     */
    public TypefaceKey(String fontName, FontStyle style) {
        this.fontName = fontName;
        this.style = style;
    }

    /**
     * Returns the font name.
     *
     * @return The font name.
     */
    public String getFontName() {
        return fontName;
    }

    /**
     * Returns the font style.
     *
     * @return The font style.
     */
    public FontStyle getStyle() {
        return style;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        TypefaceKey that = (TypefaceKey) o;

        if (!fontName.equals(that.fontName)) return false;
        return style.equals(that.style);
    }

    @Override
    public int hashCode() {
        int result = fontName.hashCode();
        result = 31 * result + style.hashCode();
        return result;
    }
}

==> org.jfree.skijagraphics2d-1.0.4-sources.jar: org/jfree/skija/TypefaceKey.java <==
/* ===============
 * SkijaGraphics2D
 * ===============
 *
 * (C)opyright 2021, by David Gilbert.
 *
 * The SkijaGraphics2D class has been developed by David Gilbert for
 * use with Orson Charts (http://www.object-refinery.com/orsoncharts) and
 * JFreeChart (http://www.jfree.org/jfreechart).  It may be useful for other
 * code that uses the Graphics2D API provided by Java2D.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *   - Neither the name of the Object Refinery Limited nor the
 *     names of its contributors may be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL OBJECT REFINERY LIMITED BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

package org.jfree.skija;

import io.github.humbleui.skija.FontStyle;

/**
 * A key used to identify a {@code Typeface} in a map used to cache items.
 */
public class TypefaceKey {

    private final String fontName;

    private final FontStyle style;

    /**
     * Creates a new key.
     *
     * @param fontName  the font name.
     * @param style  the style.
     */
    public TypefaceKey(String fontName, FontStyle style) {
        this.fontName = fontName;
        this.style = style;
    }

    /**
     * Returns the font name.
     *
     * @return The font name.
     */
    public String getFontName() {
        return fontName;
    }

    /**
     * Returns the font style.
     *
     * @return The font style.
     */
    public FontStyle getStyle() {
        return style;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        TypefaceKey that = (TypefaceKey) o;

        if (!fontName.equals(that.fontName)) return false;
        return style.equals(that.style);
    }

    @Override
    public int hashCode() {
        int result = fontName.hashCode();
        result = 31 * result + style.hashCode();
        return result;
    }
}
